==> orchestra-pvm-4.4.1-sources.jar: org/ow2/orchestra/pvm/internal/wire/binding/RetryInterceptorBinding.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.wire.binding;

import org.ow2.orchestra.pvm.internal.wire.descriptor.RetryInterceptorDescriptor;
import org.ow2.orchestra.pvm.internal.xml.Parse;
import org.ow2.orchestra.pvm.internal.xml.Parser;
import org.w3c.dom.Element;

/**
 * parses a descriptor for creating a {@link org.ow2.orchestra.pvm.internal.svc.RetryInterceptor}.
 *
 * See schema docs for more details.
 *
 * @author Tom Baeyens
 */
public class RetryInterceptorBinding extends WireInterceptorBinding {

  public RetryInterceptorBinding() {
    super("retry-interceptor");
  }

  protected RetryInterceptorDescriptor createRetryInterceptorDescriptor() {
    return new RetryInterceptorDescriptor();
  }

  public Object parse(final Element element, final Parse parse, final Parser parser) {
    final RetryInterceptorDescriptor retryInterceptorDescriptor = this.createRetryInterceptorDescriptor();

    if (element.hasAttribute("retries")) {
      final String retriesText = element.getAttribute("retries");
      try {
        final int retries = Integer.parseInt(retriesText);
        retryInterceptorDescriptor.setRetries(retries);
      } catch (final NumberFormatException e) {
        parse.addProblem("couldn't parse retries " + retriesText);
      }
    }

    if (element.hasAttribute("delay")) {
      final String delayText = element.getAttribute("delay");
      try {
        final long delay = Long.parseLong(delayText);
        retryInterceptorDescriptor.setDelay(delay);
      } catch (final NumberFormatException e) {
        parse.addProblem("couldn't parse delay " + delayText);
      }
    }

    if (element.hasAttribute("delay-factor")) {
      final String delayFactorText = element.getAttribute("delay-factor");
      try {
        final int delayFactor = Integer.parseInt(delayFactorText);
        retryInterceptorDescriptor.setDelayFactor(delayFactor);
      } catch (final NumberFormatException e) {
        parse.addProblem("couldn't parse delay-factor " + delayFactorText);
      }
    }

    return retryInterceptorDescriptor;
  }
}

==> orchestra-pvm-4.6.1-sources.jar: org/ow2/orchestra/pvm/internal/wire/binding/RetryInterceptorBinding.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.wire.binding;

import org.ow2.orchestra.pvm.internal.wire.descriptor.RetryInterceptorDescriptor;
import org.ow2.orchestra.pvm.internal.xml.Parse;
import org.ow2.orchestra.pvm.internal.xml.Parser;
import org.w3c.dom.Element;

/**
 * parses a descriptor for creating a {@link org.ow2.orchestra.pvm.internal.svc.RetryInterceptor}.
 *
 * See schema docs for more details.
 *
 * @author Tom Baeyens
 */
public class RetryInterceptorBinding extends WireInterceptorBinding {

  public RetryInterceptorBinding() {
    super("retry-interceptor");
  }

  protected RetryInterceptorDescriptor createRetryInterceptorDescriptor() {
    return new RetryInterceptorDescriptor();
  }

  public Object parse(final Element element, final Parse parse, final Parser parser) {
    final RetryInterceptorDescriptor retryInterceptorDescriptor = this.createRetryInterceptorDescriptor();

    if (element.hasAttribute("retries")) {
      final String retriesText = element.getAttribute("retries");
      try {
        final int retries = Integer.parseInt(retriesText);
        retryInterceptorDescriptor.setRetries(retries);
      } catch (final NumberFormatException e) {
        parse.addProblem("couldn't parse retries " + retriesText);
      }
    }

    if (element.hasAttribute("delay")) {
      final String delayText = element.getAttribute("delay");
      try {
        final long delay = Long.parseLong(delayText);
        retryInterceptorDescriptor.setDelay(delay);
      } catch (final NumberFormatException e) {
        parse.addProblem("couldn't parse delay " + delayText);
      }
    }

    if (element.hasAttribute("max-delay")) {
      final String delayText = element.getAttribute("max-delay");
      try {
        final long delay = Long.parseLong(delayText);
        retryInterceptorDescriptor.setMaxDelay(delay);
      } catch (final NumberFormatException e) {
        parse.addProblem("couldn't parse delay " + delayText);
      }
    }

    if (element.hasAttribute("delay-factor")) {
      final String delayFactorText = element.getAttribute("delay-factor");
      try {
        final int delayFactor = Integer.parseInt(delayFactorText);
        retryInterceptorDescriptor.setDelayFactor(delayFactor);
      } catch (final NumberFormatException e) {
        parse.addProblem("couldn't parse delay-factor " + delayFactorText);
      }
    }

    return retryInterceptorDescriptor;
  }
}
